# tiffslide changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased] - ...
...

## [0.2.2] - 2022-03-14
### Changed
- pavo: don't ship source map in wheel

## [0.2.1] - 2022-03-14
### Fixed
- pavo: updated webpack

## [0.2.0] - 2022-03-09
### Added
- pavo: configurable metadata columns
- cli: show local files for searchtree
- cli: show prod and dev settings
- cli: ship default config in package

### Fixed
- speedup cli

## [0.1.0] - 2022-03-03
### Changed
- rename `pado_visualize` to `pavo`
- major cleanup for public release

## [0.0.1] - 2021-11-25
### Added
- initial release of `pado_visualize`


[Unreleased]: https://github.com/bayer-int/pathdrive-pavo/compare/v0.2.2...HEAD
[0.2.2]: https://github.com/bayer-int/pathdrive-pavo/compare/v0.2.1...v0.2.2
[0.2.1]: https://github.com/bayer-int/pathdrive-pavo/compare/v0.2.0...v0.2.1
[0.2.0]: https://github.com/bayer-int/pathdrive-pavo/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/bayer-int/pathdrive-pavo/compare/v0.0.2...v0.1.0
[0.0.2]: https://github.com/bayer-int/pathdrive-pavo/tree/v0.0.2
